// ----------------------------------------------------------------------
// Javascript form validation routines.
// Author: Stephen Poley
//
// Simple routines to quickly pick up obvious typos.
// All validation routines return true if executed by an older browser:
// in this case validation must be left to the server.
// ----------------------------------------------------------------------

emptyString = /^\s*$/

// -----------------------------------------
//                  trim
// Trim leading/trailing whitespace off string
// -----------------------------------------

function trim(str)
{
  return str.replace(/^\s+|\s+$/g, '')
};


// -----------------------------------------
//                  msg
// Display warn/error message in HTML element
// commonCheck routine must have previously been called
// -----------------------------------------

function msg(fld,     // id of element to display message in
             msgtype, // class to give element ("warn" or "error")
             message) // string to display
{
  // setting an empty string can give problems if later set to a
  // non-empty string, so slip in an nbsp if needed
  var dispmessage;
  if (emptyString.test(message))
    dispmessage = "&nbsp;";
  else
    dispmessage = message;

  var elem = document.getElementById(fld);
  if (elem.firstChild && (elem.firstChild.nodeType == 1))
    elem.firstChild.nodeValue = dispmessage;  // DOM method
  else
    elem.innerHTML = dispmessage; // IE method

  elem.className = msgtype;
};

// -----------------------------------------
//            commonCheck
// Common code for all validation routines to:
// (a) check for older / less-equipped browsers
// (b) check if empty fields are required
// Returns true (validation passed),
//         false (validation failed) or
//         proceed (don't know yet)
// -----------------------------------------

var proceed = 2;

function commonCheck (vfld,   // element to be validated
											ifld,   // id of element to receive info/error msg
											reqd)   // true if required
{
	//    alert ("using commonCheck!");

  if (!document.getElementById)
    return true;  // not available on this browser - leave validation to the server
  var elem = document.getElementById(ifld);
  if (!elem.firstChild && (typeof elem.innerHTML != "string"))
    return true;  // not available on this browser

  if (emptyString.test(vfld.value)) {
    if (reqd) {
      msg (ifld, "query", "ERROR: Campo requerido");
      //vfld.focus();
      return false;
    }
    else {
      msg (ifld, "warn", "");   // OK
      return true;
    }
  }
  return proceed;
}

// -----------------------------------------
//            validatePresent
// Validate if something has been entered
// Returns true if so
// -----------------------------------------

function validatePresent(vfld,   // element to be validated
                         ifld )  // id of element to receive info/error msg
{
  var stat = commonCheck (vfld, ifld, true);
  if (stat != proceed) return stat;

  msg (ifld, "warn", "");
  return true;
};

// -----------------------------------------
//            checkPresent
// Chequea si hay algo en el elemento, si el navegador no es soportado devuelve true,
// si hay algo devuelve true y sino false
// -----------------------------------------

function checkPresent(vfld)   // elmento a mirara
{
 if (!document.getElementById)
    return true;  // not available on this browser - leave validation to the server

  return !emptyString.test(vfld.value);
};

// -----------------------------------------
//               validateEmail
// Validate if e-mail address
// Returns true if so (and also if could not be executed because of old browser)
// -----------------------------------------

function validateEmail  (vfld,   // element to be validated
                         ifld,   // id of element to receive info/error msg
                         reqd)   // true if required
{
  var stat = commonCheck (vfld, ifld, reqd);
  if (stat != proceed) return stat;

  var tfld = trim(vfld.value);  // value of field with whitespace trimmed off
  var email = /^[^@]+@[^@.]+\.[^@]*\w\w$/
  if (!email.test(tfld)) {
    msg (ifld, "error", "ERROR: No es una dirección de correo electrónico válida ");
    vfld.focus();
    return false;
  }

  var email2 = /^[A-Za-z][\w.-]+@\w[\w.-]+\.[\w.-]*[A-Za-z][A-Za-z]$/
  if (!email2.test(tfld))
    msg (ifld, "warn", "Es una dirección de correo electrónico poco usual, verifique que sea correcta.");
  else
    msg (ifld, "warn", "");
  return true;
};


// -----------------------------------------
//            validateTelnr
// Validate telephone number
// Returns true if so (and also if could not be executed because of old browser)
// Permits spaces, hyphens, brackets and leading +
// -----------------------------------------

function validateTelnr  (vfld,   // element to be validated
                         ifld,   // id of element to receive info/error msg
                         reqd)   // true if required
{
  var stat = commonCheck (vfld, ifld, reqd);
  if (stat != proceed) return stat;

  var tfld = trim(vfld.value);  // value of field with whitespace trimmed off
  var telnr = /^\+?[0-9 ()-]+[0-9]$/
  if (!telnr.test(tfld)) {
    msg (ifld, "error", "ERROR: No es un numero de teléfono válido. Los caracteres permitidos son:  números, espacio, (, ), -.");
    // not a valid telephone number. Characters permitted are digits, space ()- and leading +");
    vfld.focus();
    return false;
  }

  var numdigits = 0;
  for (var j=0; j<tfld.length; j++)
    if (tfld.charAt(j)>='0' && tfld.charAt(j)<='9') numdigits++;

  if (numdigits<6) {
    msg (ifld, "error", "ERROR: " + numdigits + " dígitos - es muy corto");
    vfld.focus();
    return false;
  }

  if (numdigits>14)
    msg (ifld, "warn", numdigits + " dígitos -  verifique que sea correcto");
  else {
    if (numdigits<10)
      msg (ifld, "warn", "Solo " + numdigits + " dígitos -  verifique que sea correcto");
    else
      msg (ifld, "warn", "");
  }
  return true;
};

// -----------------------------------------
//             validateAge
// Validate person's age
// Returns true if OK
// -----------------------------------------

function validateAge    (vfld,   // element to be validated
                         ifld,   // id of element to receive info/error msg
                         reqd)   // true if required
{
  var stat = commonCheck (vfld, ifld, reqd);
  if (stat != proceed) return stat;

  var tfld = trim(vfld.value);
  var ageRE = /^[0-9]{1,3}$/
  if (!ageRE.test(tfld)) {
    msg (ifld, "error", "ERROR: no es una edad valida.");
    vfld.focus();
    return false;
  }

  if (tfld>=200) {
    msg (ifld, "error", "ERROR: no es una edad valida.");
    vfld.focus();
    return false;
  }

  if (tfld>120) msg (ifld, "warn", "ERROR: la edad es mayor que 120 años verifique que sea correcto.");
  else {
    if (tfld<7) msg (ifld, "warn", "ERROR: la edad es menor que 7 años verifique que sea correcto.");
    else        msg (ifld, "warn", "");
  }
  return true;
};


// -----------------------------------------
//             validateMinSize
// Verifica que un campo tenga como m�nimo <size> caracteres de largo
//
// -----------------------------------------

function validateMinSize (vfld,   // element to be validated
                         ifld,   // id of element to receive info/error msg
                         size,
                         reqd)   // true if required
{
  var stat = commonCheck (vfld, ifld, reqd);
  if (stat != proceed) return stat;

  var tfld = trim(vfld.value);

  if (tfld.length() < size) {
    msg (ifld, "error", "ERROR: Tiene que tener más de "+size+" caracteres de longitud.");
    vfld.focus();
    return false;
  }
  return true;
};

// -----------------------------------------
//             validatePasswordRep
// Verifica que la repetición de la contraseña coincida con la contraseña.
//
// -----------------------------------------

function validatePasswordRep (vfld,   // element to be validated
                              ifld,   // id of element to receive info/error msg
                              cfld,   // Campo con el que va a ser comparado.
                              reqd)   // true if required
{
  var stat = commonCheck (vfld, ifld, reqd);
  if (stat != proceed) return stat;

  //var tfld = trim(vfld.value);

  //var elem = document.getElementById(cfld);

  if (vfld.value!=cfld.value) {
    msg (ifld, "error", "ERROR: No coinciden las contraseñas. <BR/> Intente reingresar los dos campos de contraseña.");
   // vfld.focus();
    return false;
  }
  msg (ifld, "warn", "");
  return true;
};


// -----------------------------------------
//            validateNr
// Validate  number
// Returns true if so (and also if could not be executed because of old browser)

// -----------------------------------------
function validateNr     (vfld,   // element to be validated
                         ifld,   // id of element to receive info/error msg
                         reqd)   // true if required
{
	var numbers = /^[0-9\.]+$/;
	var stat = commonCheck (vfld, ifld, reqd);
	if (stat != proceed) return stat;
	
	if (!numbers.test(vfld.value)) {
		msg (ifld, "query", "ERROR: El campo debe ser numérico");
		vfld.focus();
		return false;
	}
	msg (ifld, "warn", "");
	return true;
};




// -----------------------------------------
//             validateMinSize
// Verifica que un campo tenga como mínimo <size> caracteres de largo
//
// -----------------------------------------
function validateNrSize (vfld,   // element to be validated
                         ifld,   // id of element to receive info/error msg
                         minsize,
			 maxsize,
                         reqd)   // true if required

{
   var numbers = /^[0-9]+$/;
   var stat = commonCheck (vfld, ifld, reqd);
   if (stat != proceed) return stat;

   var tfld = trim(vfld.value);

   if (tfld.length <= minsize) {
       msg (ifld, "error", "ERROR: Debe tener más de "+minsize+" caracteres de longitud.");
       vfld.focus();
       return false;
   } else if (tfld.length >= maxsize) {
       msg (ifld, "error", "ERROR: Debe tener menos de "+maxsize+" caracteres de longitud.");
       vfld.focus();
       return false;
   } else if (!numbers.test(vfld.value)) {
       msg (ifld, "error", "ERROR: El campo tiene que ser numérico.");
       vfld.focus();
       return false;
   }
   msg (ifld, "warn", "");
   return true;
};

var voicemail_requerido=false;

function validateVoicemails() {
	if (checkPresent(document.forms.formulario.voicemail)) {
		voicemail_requerido=true;
	}
	else {
		voicemail_requerido=false;
	}
	val1 = validateNr(document.forms.formulario.voicemail, 'inf_voicemail', voicemail_requerido);
	val2 = validateNr(document.forms.formulario.password, 'inf_password', voicemail_requerido);
	
	return val1 && val2;
}

